package com.aucma.dms.mapper;

//import com.aucma.dms.domain.DmsBaseAlarmRule;

import com.aucma.dms.domain.DmsBaseAlarmRule;

import java.util.List;

/**
 * 设备报警规则Mapper接口
 *
 * @author Yinq
 * @date 2024-08-13
 */
public interface DmsBaseAlarmRuleMapper {
    /**
     * 查询设备报警规则
     *
     * @param alarmRuleId 设备报警规则主键
     * @return 设备报警规则
     */
    public DmsBaseAlarmRule selectDmsBaseAlarmRuleByAlarmRuleId(Long alarmRuleId);

    /**
     * 查询设备报警规则列表
     *
     * @param dmsBaseAlarmRule 设备报警规则
     * @return 设备报警规则集合
     */
    public List<DmsBaseAlarmRule> selectDmsBaseAlarmRuleList(DmsBaseAlarmRule dmsBaseAlarmRule);

    /**
     * 新增设备报警规则
     *
     * @param dmsBaseAlarmRule 设备报警规则
     * @return 结果
     */
    public int insertDmsBaseAlarmRule(DmsBaseAlarmRule dmsBaseAlarmRule);

    /**
     * 修改设备报警规则
     *
     * @param dmsBaseAlarmRule 设备报警规则
     * @return 结果
     */
    public int updateDmsBaseAlarmRule(DmsBaseAlarmRule dmsBaseAlarmRule);

    /**
     * 删除设备报警规则
     *
     * @param alarmRuleId 设备报警规则主键
     * @return 结果
     */
    public int deleteDmsBaseAlarmRuleByAlarmRuleId(Long alarmRuleId);

    /**
     * 批量删除设备报警规则
     *
     * @param alarmRuleIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteDmsBaseAlarmRuleByAlarmRuleIds(Long[] alarmRuleIds);
}
